=====
postal_code
=====

postal_code is a Django app to verify if the cap of a Nation is valid.

Quick start
-----------

1. Add "postal_code" to your INSTALLED_APPS setting like this::

    INSTALLED_APPS = [
        ...
        'postal_code',
    ]
